Method: Chain::Config::Info#build_date

Defined in:
lib/chain/config.rb

#build_dateString (readonly)

Date when the core binary was compiled.

The API may not return this field as an RFC3399 timestamp, so it is not converted into a Time object.

Returns:

  • (String)


126
# File 'lib/chain/config.rb', line 126

attrib :build_date